@@ -43,7 +43,9 @@ public:
     enum ZigbeeBackendType {
         ZigbeeBackendTypeDeconz,
         ZigbeeBackendTypeNxp,
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         ZigbeeBackendTypeTi
+#endif
     };
     Q_ENUM(ZigbeeBackendType)
 
